Assystent domowy
=================================================================================

Open source home automation platform that puts local control and privacy first.
We are able to track and control all devices at home and offer a control by voice and automating the control.


|screenshot-states|


.. |screenshot-states| image:: https://raw.github.com/sviete/AIS-home-assistant/master/docs/screenshots.png
   :target: https://www.ai-speaker.com
